package com.chinaweal.aiccs.aiccs.statistic.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaweal.aiccs.aiccs.statistic.entity.StatisticsResult;
import com.chinaweal.aiccs.aiccs.statistic.mapper.StatisticsResultMapper;
import com.chinaweal.aiccs.aiccs.statistic.service.IStatisticsResultService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 定时统计结果存储表 服务实现类
 * </p>
 *
 * @author chinaweal
 * @since 2020-08-05
 */
@Service
public class StatisticsResultServiceImpl extends ServiceImpl<StatisticsResultMapper, StatisticsResult> implements IStatisticsResultService {

    @Override
    public StatisticsResult getLatest(String moduleTag) {
        return baseMapper.selectLatest(moduleTag);
    }

    @Override
    public List<Map<String, String>> staticAllRegionTsabnlist() {
        return baseMapper.staticAllRegionTsabnlist();
    }

    @Override
    public List<Map<String, Integer>> staticAbnByYear() {
        return baseMapper.staticAbnByYear();
    }

    @Override
    public List<Map<String, Integer>> staticAbnByMonth() {
        return baseMapper.staticAbnByMonth();
    }

    @Override
    public List<Map<String, Integer>> staticAbnByWeek() {
        return baseMapper.staticAbnByWeek();
    }

    @Override
    public List<Map<String, String>> staticAbnByIn() {
        return baseMapper.staticAbnByIn();
    }

    @Override
    public List<Map<String, Integer>> staticAbnByOut() {
        return baseMapper.staticAbnByOut();
    }

    @Override
    public List<Map<String, String>> staticAllRegionTsserill() {
        return baseMapper.staticAllRegionTsserill();
    }

    @Override
    public List<Map<String, Integer>> staticTsserillByYear() {
        return baseMapper.staticTsserillByYear();
    }

    @Override
    public List<Map<String, Integer>> staticTsserillByIn() {
        return baseMapper.staticTsserillByIn();
    }

    @Override
    public List<Map<String, String>> staticTsserillByOutRe() {
        return baseMapper.staticTsserillByOutRe();
    }

    @Override
    public List<Map<String, String>> staticRevRegion() {
        return baseMapper.staticRevRegion();
    }

    @Override
    public List<Map<String, Integer>> staticRevYear() {
        return baseMapper.staticRevYear();
    }

    @Override
    public List<Map<String, String>> staticLockRegion() {
        return baseMapper.staticLockRegion();
    }

    @Override
    public List<Map<String, Integer>> staticLockType() {
        return baseMapper.staticLockType();
    }

    @Override
    public List<Map<String, String>> staticFraudRegion() {
        return baseMapper.staticFraudRegion();
    }

    @Override
    public List<Map<String, Integer>> staticFraudYear() {
        return baseMapper.staticFraudYear();
    }

    @Override
    public List<Map<String, Integer>> staticFraudType() {
        return baseMapper.staticFraudType();
    }

    @Override
    public List<Map<String, String>> staticTsusualinspectRegion() {
        return baseMapper.staticTsusualinspectRegion();
    }

    @Override
    public List<Map<String, Integer>> staticTsusualinspectType() {
        return baseMapper.staticTsusualinspectType();
    }

}
