package com.chinaweal.aiccs.aiccs.statistic.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.chinaweal.aiccs.aiccs.statistic.entity.StatisticsResult;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 定时统计结果存储表 服务类
 * </p>
 *
 * @author chinaweal
 * @since 2020-08-05
 */
public interface IStatisticsResultService extends IService<StatisticsResult> {

    /**
     * 获取最近的统计
     */
    StatisticsResult getLatest(String moduleTag);

    List<Map<String, String>> staticAllRegionTsabnlist();

    List<Map<String, Integer>> staticAbnByYear();

    List<Map<String, Integer>> staticAbnByMonth();

    List<Map<String, Integer>> staticAbnByWeek();

    List<Map<String, String>> staticAbnByIn();

    List<Map<String, Integer>> staticAbnByOut();

    List<Map<String, String>> staticAllRegionTsserill();

    List<Map<String, Integer>> staticTsserillByYear();

    List<Map<String, Integer>> staticTsserillByIn();

    List<Map<String, String>> staticTsserillByOutRe();

    List<Map<String, String>> staticRevRegion();

    List<Map<String, Integer>> staticRevYear();

    List<Map<String, String>> staticLockRegion();

    List<Map<String, Integer>> staticLockType();

    List<Map<String, String>> staticFraudRegion();

    List<Map<String, Integer>> staticFraudYear();

    List<Map<String, Integer>> staticFraudType();

    List<Map<String, String>> staticTsusualinspectRegion();

    List<Map<String, Integer>> staticTsusualinspectType();
}
